@@ -1,6 +1,6 @@
 "variogram.line" <-
 function(object, maxdist, n=200, min=1.0e-6 * maxdist, dir = c(1,0,0), 
-	covariance = FALSE,	...)
+	covariance = FALSE,	..., debug.level = 0)
 {
 	if (missing(object))
 		stop("model is missing");
@@ -10,6 +10,7 @@ function(object, maxdist, n=200, min=1.0e-6 * maxdist, dir = c(1,0,0),
 		stop("maxdist is missing");
 	if (length(dir) != 3)
 		stop("dir should be numeric vector of length 3")
+	.Call("gstat_init", as.integer(debug.level))
 	pars = c(min,maxdist,n,dir)
 	load.variogram.model(object, c(0,0)) # loads object into gstat 
 	ret = .Call("gstat_variogram_values", as.integer(c(0,0)),
