@@ -1,5 +1,5 @@
 "xyz2img" <-
-function (xyz, zcol = 3, xcol = 1, ycol = 2) 
+function (xyz, zcol = 3, xcol = 1, ycol = 2, tolerance = 10 * .Machine$double.eps) 
 {
     if (ncol(xyz) < 3) 
         stop("xyz object should have at least three columns")
@@ -12,25 +12,23 @@ function (xyz, zcol = 3, xcol = 1, ycol = 2)
     ny = length(yy)
     nmax = max(nx, ny)
     difx = diff(xx)
-    if (diff(range(unique(difx))) > 1e-15) 
+    if (diff(range(unique(difx))) > tolerance) 
         stop("x intervals are not constant")
     dify = diff(yy)
-    if (diff(range(unique(dify))) > 1e-15) 
+    if (diff(range(unique(dify))) > tolerance) 
         stop("y intervals are not constant")
-    dx = difx[1]
-    dy = dify[1]
-    ratio = (nx * dx)/(ny * dy)
+    dx = mean(difx)
+    dy = mean(dify)
     xmin = min(xx)
     xmax = max(xx)
     xrange = xmax - xmin
     ymin = min(yy)
     ymax = max(yy)
     yrange = ymax - ymin
-    zz = matrix(NA, nrow = nx, ncol = ny)
-    xx = seq(xmin, xmax, dx)
-    yy = seq(ymin, ymax, dy)
     row = round((x - xmin)/dx) + 1
     col = round((y - ymin)/dy) + 1
-    for (i in 1:length(x)) zz[row[i], col[i]] = z[i]
-    list(x = xx, y = yy, z = zz)
+	zz = rep(as.numeric(NA), nx * ny)
+	zz[row + nx * (col - 1)] = z
+	zz = matrix(zz, nrow = nx, ncol = ny)
+    list(x = seq(xmin, xmax, dx), y = seq(ymin, ymax, dy), z = zz)
 }
